==> igniteui-react-charts-16.4.1.tgz: package/ES2015/SplineAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { SplineSeriesBase } from "./SplineSeriesBase";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, runOn, markType } from "igniteui-react-core/ES2015/type";
import { Path } from "igniteui-react-core/ES2015/Path";
import { ScalerParams } from "./ScalerParams";
import { SplineSeriesBaseView } from "./SplineSeriesBaseView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES2015/Color";
export class SplineAreaSeries extends SplineSeriesBase {
    constructor() {
        super();
        this.qh = null;
        this.qh = new CategoryLineRasterizer();
        this.ab = SplineAreaSeries.$;
    }
    bf() {
        return new SplineAreaSeriesView(this);
    }
    m7() {
        return 1;
    }
    il(a) {
        super.il(a);
        this.qi = a;
    }
    preferredCategoryMode(a) {
        return 0;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.c6();
    }
    df(a, b) {
        let c = this.lc(this.lf(a), true, false);
        if (this.py(a, c, b)) {
            return true;
        }
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    oe(a, b) {
        super.oe(a, b);
        let c = this.m6.cl.d;
        let d = typeCast(SplineAreaSeriesView.$, b);
        let e = a.f;
        let f = this.getEffectiveViewport1(b);
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        let g = false;
        let h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            let i = new ScalerParams(0, b.bq, b.bp, this.po.b8, f);
            this.oa(e, -1, this.valueColumn.count, this.po, i, b.n);
        }
        let j = d.dd;
        let k = d.de;
        let l = d.dg;
        let m = d.di;
        this.m5.ae(j, true, false, true, true);
        this.m5.ae(k, true, false, true, true);
        this.m5.ae(l, false, true, false, false);
        this.m5.ae(m, false, true, false, false);
        l._opacity = this.m5.i * this.d2;
        m._opacity = 0.5 * this.m5.i * this.d2;
        if (b.cp(a)) {
            d.c8(a.f.count, e, true, c, this.eq, (n, o, p, q, r) => this.o8(n, a.f.count, b), 1, a.f.count == 1 ? null : this.on(e, e.count - 1, b.bp, b.bq, true));
            b.cs(a);
        }
        let n = this.fetchYAxis();
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
SplineAreaSeries.$t = markType(SplineAreaSeries, 'SplineAreaSeries', SplineSeriesBase.$);
export class SplineAreaSeriesView extends SplineSeriesBaseView {
    constructor(a) {
        super(a);
        this.c5 = null;
        this.df = new Path();
        this.dj = new Path();
        this.dh = new Path();
        this.dk = new Path();
        this.c9 = new Path();
        this.db = new Path();
        this.da = new Path();
        this.dc = new Path();
        this.c5 = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    get dd() {
        return this.dj;
    }
    get de() {
        return this.dk;
    }
    get dg() {
        return this.df;
    }
    get di() {
        return this.dh;
    }
    c6() {
        this.df.aj = null;
        this.dh.aj = null;
        this.dj.aj = null;
        this.dk.aj = null;
        this.an();
    }
    c7(a, b, c, d, e, f, g) {
        this.c8(a, b, c, d, e, f, g, null);
    }
    c8(a, b, c, d, e, f, g, h) {
        this.c5.qh.a = typeCast(ISortingAxis_$type, this.cn.fetchXAxis()) !== null ? true : false;
        this.c5.qh.j(this.df, this.dj, this.dh, this.dk, a, b, c, d, e, f, g, h);
        this.an();
    }
    a9() {
        super.a9();
        this.c9.aj = this.df.aj;
        this.db.aj = this.dj.aj;
        this.da.aj = this.dh.aj;
        this.dc.aj = this.dk.aj;
        let a = this.bk();
        this.c9._fill = a;
        this.c9._opacity = 1;
        this.da._fill = a;
        this.da._opacity = 1;
        this.db._stroke = a;
        this.db.ac = this.e.eu + 3;
        this.dc._stroke = a;
        this.dc.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (b) {
            a.s(this.c9);
            a.s(this.da);
            a.s(this.db);
            a.s(this.dc);
        }
        else {
            a.s(this.df);
            a.s(this.dh);
            a.s(this.dj);
            a.s(this.dk);
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.dj, "lowerShape", ["Lower"]);
        this.e.a2.exportPathData(a, this.dk, "upperShape", ["Upper", "Main"]);
        this.e.a2.exportPathData(a, this.dh, "translucentShape", ["Translucent"]);
        this.e.a2.exportPathData(a, this.df, "fillShape", ["Fill"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 5;
        this.e.es = 1;
        this.e.et = -3;
    }
}
SplineAreaSeriesView.$t = markType(SplineAreaSeriesView, 'SplineAreaSeriesView', SplineSeriesBaseView.$);

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/SplineAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { SplineSeriesBase } from "./SplineSeriesBase";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { typeCast, runOn, markType } from "igniteui-react-core/ES2015/type";
import { Path } from "igniteui-react-core/ES2015/Path";
import { ScalerParams } from "./ScalerParams";
import { SplineSeriesBaseView } from "./SplineSeriesBaseView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES2015/Color";
export class SplineAreaSeries extends SplineSeriesBase {
    constructor() {
        super();
        this.qi = null;
        this.qi = new CategoryLineRasterizer();
        this.ab = SplineAreaSeries.$;
    }
    bf() {
        return new SplineAreaSeriesView(this);
    }
    m7() {
        return 1;
    }
    il(a) {
        super.il(a);
        this.qj = a;
    }
    preferredCategoryMode(a) {
        return 0;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.c8();
    }
    df(a, b) {
        let c = this.lc(this.lf(a), true, false);
        if (this.pz(a, c, b)) {
            return true;
        }
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    of(a, b) {
        super.of(a, b);
        let c = this.m6.cn.d;
        let d = typeCast(SplineAreaSeriesView.$, b);
        let e = a.f;
        let f = this.getEffectiveViewport1(b);
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        let g = false;
        let h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            let i = new ScalerParams(0, b.bs, b.br, this.pp.b8, f);
            this.ob(e, -1, this.valueColumn.count, this.pp, i, b.n);
        }
        let j = d.df;
        let k = d.dg;
        let l = d.di;
        let m = d.dk;
        this.m5.ae(j, true, false, true, true);
        this.m5.ae(k, true, false, true, true);
        this.m5.ae(l, false, true, false, false);
        this.m5.ae(m, false, true, false, false);
        l._opacity = this.m5.i * this.d2;
        m._opacity = 0.5 * this.m5.i * this.d2;
        if (b.cr(a)) {
            d.da(a.f.count, e, true, c, this.eq, (n, o, p, q, r) => this.o9(n, a.f.count, b), 1, a.f.count == 1 ? null : this.oo(e, e.count - 1, b.br, b.bs, true));
            b.cu(a);
        }
        let n = this.fetchYAxis();
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
SplineAreaSeries.$t = markType(SplineAreaSeries, 'SplineAreaSeries', SplineSeriesBase.$);
export class SplineAreaSeriesView extends SplineSeriesBaseView {
    constructor(a) {
        super(a);
        this.c7 = null;
        this.dh = new Path();
        this.dl = new Path();
        this.dj = new Path();
        this.dm = new Path();
        this.db = new Path();
        this.dd = new Path();
        this.dc = new Path();
        this.de = new Path();
        this.c7 = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    get df() {
        return this.dl;
    }
    get dg() {
        return this.dm;
    }
    get di() {
        return this.dh;
    }
    get dk() {
        return this.dj;
    }
    c8() {
        this.dh.aj = null;
        this.dj.aj = null;
        this.dl.aj = null;
        this.dm.aj = null;
        this.an();
    }
    c9(a, b, c, d, e, f, g) {
        this.da(a, b, c, d, e, f, g, null);
    }
    da(a, b, c, d, e, f, g, h) {
        this.c7.qi.a = typeCast(ISortingAxis_$type, this.cp.fetchXAxis()) !== null ? true : false;
        this.c7.qi.j(this.dh, this.dl, this.dj, this.dm, a, b, c, d, e, f, g, h);
        this.an();
    }
    a9() {
        super.a9();
        this.db.aj = this.dh.aj;
        this.dd.aj = this.dl.aj;
        this.dc.aj = this.dj.aj;
        this.de.aj = this.dm.aj;
        let a = this.bl();
        this.db._fill = a;
        this.db._opacity = 1;
        this.dc._fill = a;
        this.dc._opacity = 1;
        this.dd._stroke = a;
        this.dd.ac = this.e.eu + 3;
        this.de._stroke = a;
        this.de.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (b) {
            a.s(this.db);
            a.s(this.dc);
            a.s(this.dd);
            a.s(this.de);
        }
        else {
            a.s(this.dh);
            a.s(this.dj);
            a.s(this.dl);
            a.s(this.dm);
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.dl, "lowerShape", ["Lower"]);
        this.e.a2.exportPathData(a, this.dm, "upperShape", ["Upper", "Main"]);
        this.e.a2.exportPathData(a, this.dj, "translucentShape", ["Translucent"]);
        this.e.a2.exportPathData(a, this.dh, "fillShape", ["Fill"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 5;
        this.e.es = 1;
        this.e.et = -3;
    }
}
SplineAreaSeriesView.$t = markType(SplineAreaSeriesView, 'SplineAreaSeriesView', SplineSeriesBaseView.$);
